---
title: Overview
page_title: DropDownList Overview - Components - Kendo UI for Vue
description: "Get an overview of the features the Kendo UI DropDownList wrapper for Vue delivers and use the component in Vue projects."
slug: overview_dropdownlist
position: 1
---

# DropDownList Overview

The DropDownList provides a list of predefined options and allows for a single item selection from that list.

The DropDownList wrapper for Vue is a client-side wrapper for the [Kendo UI DropDownList](https://docs.telerik.com/kendo-ui/api/javascript/ui/dropdownlist) widget.

## Basic Usage

The following example demonstrates the DropDownList in action.

```html-preview
<div id="vueapp" class="vue-app">
    DropDownList value: {{ dropdownlistValue }}
    <br />
    <br />
    <kendo-dropdownlist v-model="dropdownlistValue"
                        :data-source="dataSourceArray"
                        :data-text-field="'text'"
                        :data-value-field="'value'"
                        :filter="'contains'">
    </kendo-dropdownlist>
</div>
```
```js
Vue.use(DropdownsInstaller);

new Vue({
    el: "#vueapp",
    data: function() {
        return {
            dropdownlistValue: "",
            dataSourceArray: [
                { text: 'Small', value: '1' },
                { text: 'Medium', value: '2' },
                { text: 'Large', value: '3' },
                { text: 'X-Large', value: '4' },
                { text: '2X-Large', value: '5' }
            ]
        }
    }
})
```

## Functionality and Features

* [Data binding]({% slug databinding_dropdownlist %})
* [Filtering]({% slug filtering_dropdownlist %})
* [Virtualization]({% slug virtualization_dropdownlist %})
* [Grouping]({% slug grouping_dropdownlist %})
* [Cascading DropDownLists]({% slug cascading_dropdownlist %})
* [Templates]({% slug templates_dropdownlist %})
* [Keyboard navigation]({% slug keyboard_navigation_dropdownlist %})
* [RTL support]({% slug rtl_support_dropdownlist %})

## Events

The following example demonstrates basic DropDownList events. You can subscribe to [all DropDownList events](https://docs.telerik.com/kendo-ui/api/javascript/ui/dropdownlist#events) by the handler name.

```html
<div id="vueapp" class="vue-app">
    <kendo-dropdownlist :data-source="dataSourceArray"
                        :data-text-field="'text'"
                        :data-value-field="'value'"
                        :filter="'contains'"
                        :options-label="'Select country'"
                        @change="onChange"
                        @close="onClose"
                        @dataBound="onDataBound"
                        @filtering="onFiltering"
                        @open="onOpen"
                        @select="onSelect"
                        @cascade="onCascade">
    </kendo-dropdownlist>
</div>
```
```js
Vue.use(DropdownsInstaller);

new Vue({
    el: "#vueapp",
    data: function() {
        return {
            dataSourceArray: [
                { text: 'Albania', value: '1' },
                { text: 'Andorra', value: '2' },
                { text: 'Armenia', value: '3' },
                { text: 'Austria', value: '4' },
                { text: 'Azerbaijan', value: '5' },
                { text: 'Belarus', value: '6' },
                { text: 'Belgium', value: '7' }
            ]
        }
    },
    methods: {
        onChange: function(e) {
            console.log("Event :: change");
        },
        onClose: function(e) {
            console.log("Event :: close");
        },
        onDataBound: function(e) {
            console.log("Event :: dataBound");
        },
        onFiltering: function(e) {
            console.log("Event :: filtering");
        },
        onOpen: function(e) {
            console.log("Event :: open");
        },
        onSelect: function(e) {
            console.log("Event :: select");
        },
        onCascade: function(e) {
            console.log("Event :: cascade")
        }
    }
})
```

## Suggested Links

* [Kendo UI DropDownList for jQuery](https://docs.telerik.com/kendo-ui/controls/editors/dropdownlist/overview)
* [API Reference of the DropDownList Widget](https://docs.telerik.com/kendo-ui/api/javascript/ui/dropdownlist)
