---
title: Virtualization
page_title: Virtualization - DropDownList - Kendo UI for Vue
description: "Use the virtualization features of the Kendo UI DropDownList wrapper for Vue which allow you to handle large datasets."
slug: virtualization_dropdownlist
position: 4
---

# Virtualization

Virtualization allows you to display large sets of data.

Regardless of the dataset size, the UI virtualization technique uses a fixed amount of list items in the popup list of the component. When the list is scrolled, the DropDownList reuses the existing items to display the relevant data instead of creating new data.

The following example demonstrates how to set the minimum configuration of the DropDownList and the DataSource to enable the virtualization.

```html-preview
<div id="vueapp" class="vue-app">
    <kendo-datasource ref="datasource"
                      :type="'odata'"
                      :transport-read-url="'https://demos.telerik.com/kendo-ui/service/Northwind.svc/Orders'"
                      :schema-model-fileds="fields"
                      :server-filtering="true"
                      :server-paging="true"
                      :page-size="40">
    </kendo-datasource>
    <kendo-dropdownlist ref="dropdownlist"
                        :data-source-ref="'datasource'"
                        :data-text-field="'ShipName'"
                        :data-value-field="'OrderID'"
                        :virtual-value-mapper="valueMapperFunction"
                        :virtual-item-height="26"
                        :height="260"
                        style="width:400px;"
                        :template="itemTemplate">
    </kendo-dropdownlist>
</div>
```
```js
Vue.use(DropdownsInstaller);
Vue.use(DataSourceInstaller);

new Vue({
    el: "#vueapp",
    methods: {
        convertValues (value) {
            var data = {}
            value = $.isArray(value) ? value : [value]

            for (var idx = 0; idx < value.length; idx++) {
                data['values[' + idx + ']'] = value[idx]
            }

            return data
        },
        valueMapperFunction: function (options) {
            var that = this;

            $.ajax({
                url: 'https://demos.telerik.com/kendo-ui/service/Orders/ValueMapper',
                type: 'GET',
                dataType: 'jsonp',
                data: that.convertValues(options.value),
                success: function (data) {
                    options.success(data)
                }
            })
        },
    },
    data: {
        fields: {
            OrderID: { type: 'number' },
            Freight: { type: 'number' },
            ShipName: { type: 'string' },
            OrderDate: { type: 'date' },
            ShipCity: { type: 'string' }
        },
        itemTemplate: '<strong>#= OrderID #</strong> - #= ShipName #, #= ShipCountry #'
    },
    mounted() {
        var dropdownlist = this.$refs.dropdownlist.kendoWidget()
        dropdownlist.value(10600)
    }
})
```

## Suggested Links

* [Kendo UI DropDownList for jQuery](https://docs.telerik.com/kendo-ui/controls/editors/dropdownlist/overview)
* [API Reference of the DropDownList Widget](https://docs.telerik.com/kendo-ui/api/javascript/ui/dropdownlist)
