---
title: Overview
page_title: MultiSelect Overview - Components - Kendo UI for Vue
description: "Get an overview of the features the Kendo UI MultiSelect wrapper for Vue delivers and use the component in Vue projects."
slug: overview_multiselect
position: 1
---

# MultiSelect Overview

The MultiSelect provides a predefined list for multiple item selection.

The MultiSelect wrapper for Vue is a client-side wrapper for the [Kendo UI MultiSelect](https://docs.telerik.com/kendo-ui/api/javascript/ui/multiselect) widget.

## Basic Usage

The following example demonstrates the MultiSelect in action.

```html-preview
<div id="vueapp" class="vue-app">
    MultiSelect value: {{ multiselectValue }}
    <br />
    <br />
    <kendo-multiselect v-model="multiselectValue"
                        :data-source="dataSourceArray"
                        :data-text-field="'text'"
                        :data-value-field="'value'"
                        :placeholder="'Select size...'"
                        :filter="'contains'">
    </kendo-multiselect>
</div>
```
```js
Vue.use(DropdownsInstaller);

new Vue({
    el: "#vueapp",
    data: function() {
        return {
            multiselectValue: "",
            dataSourceArray: [
                { text: 'Baseball', value: '1' },
                { text: 'Basketball', value: '2' },
                { text: 'Cricket', value: '3' },
                { text: 'Football', value: '4' },
                { text: 'Tennis', value: '5' },
                { text: 'Volleyball', value: '6' }
            ]
        }
    }
})
```

## Functionality and Features

* [Data binding]({% slug databinding_multiselect %})
* [Filtering]({% slug filtering_multiselect %})
* [Virtualization]({% slug virtualization_multiselect %})
* [Grouping]({% slug grouping_multiselect %})
* [Tag mode]({% slug tag_mode_multiselect %})
* [Templates]({% slug templates_multiselect %})
* [Keyboard Nnvigation]({% slug keyboard_navigation_multiselect %})
* [RTL support]({% slug rtl_support_multiselect %})

## Events

The following example demonstrates basic MultiSelect events. You can subscribe to [all MultiSelect events](https://docs.telerik.com/kendo-ui/api/javascript/ui/multiselect#events) by the handler name.

```html
<div id="vueapp" class="vue-app">
    <kendo-multiselect :data-source="dataSourceArray"
                       :data-text-field="'text'"
                       :data-value-field="'value'"
                       :filter="'contains'"
                       :placeholder="'Select sports...'"
                        @change="onChange"
                        @close="onClose"
                        @dataBound="onDataBound"
                        @filtering="onFiltering"
                        @open="onOpen"
                        @select="onSelect"
                        @deselect="onDeselect">
    </kendo-multiselect>
</div>
```
```js
Vue.use(DropdownsInstaller);

new Vue({
    el: "#vueapp",
    data: function() {
        return {
            dataSourceArray: [
                { text: 'Baseball', value: '1' },
                { text: 'Basketball', value: '2' },
                { text: 'Cricket', value: '3' },
                { text: 'Football', value: '4' },
                { text: 'Tennis', value: '5' },
                { text: 'Volleyball', value: '6' }
            ]
        }
    },
    methods: {
        onChange: function(e) {
            console.log("Event :: change");
        },
        onClose: function(e) {
            console.log("Event :: close");
        },
        onDataBound: function(e) {
            console.log("Event :: dataBound");
        },
        onFiltering: function(e) {
            console.log("Event :: filtering");
        },
        onOpen: function(e) {
            console.log("Event :: open");
        },
        onSelect: function(e) {
            console.log("Event :: select");
        },
        onDeselect: function(e) {
            console.log("Event :: deselect")
        }
    }
})
```

## Suggested Links

* [Kendo UI MultiSelect for jQuery](https://docs.telerik.com/kendo-ui/controls/editors/multiselect/overview)
* [API Reference of the MultiSelect Widget](https://docs.telerik.com/kendo-ui/api/javascript/ui/multiselect)
